@@ -23,16 +23,15 @@
   @NOTATION@
 */
 
+#include "config.h"
 #include <string.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#include <bonobo/bonobo-dock.h>
-#include <bonobo/bonobo-dock-band.h>
-#include <bonobo/bonobo-dock-item.h>
-#include <libgnome/gnome-macros.h>
+#include "bonobo-dock.h"
+#include "bonobo-dock-band.h"
+#include "bonobo-dock-item.h"
 
-GNOME_CLASS_BOILERPLATE (BonoboDock, bonobo_dock,
-			 GtkContainer, GTK_TYPE_CONTAINER);
+G_DEFINE_TYPE (BonoboDock, bonobo_dock, GTK_TYPE_CONTAINER)
 
 #define noBONOBO_DOCK_DEBUG
 
@@ -78,7 +77,6 @@ static void     bonobo_dock_forall              (GtkContainer *container,
                                                 gboolean include_internals,
                                                 GtkCallback callback,
                                                 gpointer callback_data);
-static void     bonobo_dock_destroy             (GtkObject *object);
 static void     bonobo_dock_finalize            (GObject *object);
 
 static void     size_request_v                 (GList *list,
@@ -168,7 +166,6 @@ bonobo_dock_class_init (BonoboDockClass *class)
   widget_class = (GtkWidgetClass *) class;
   container_class = (GtkContainerClass *) class;
 
-  object_class->destroy = bonobo_dock_destroy;
   gobject_class->finalize = bonobo_dock_finalize;
 
   widget_class->size_request = bonobo_dock_size_request;
@@ -193,7 +190,7 @@ bonobo_dock_class_init (BonoboDockClass *class)
 }
 
 static void
-bonobo_dock_instance_init (BonoboDock *dock)
+bonobo_dock_init (BonoboDock *dock)
 {
   GTK_WIDGET_SET_FLAGS (GTK_WIDGET (dock), GTK_NO_WINDOW);
 
@@ -485,7 +482,7 @@ bonobo_dock_map (GtkWidget *widget)
   g_return_if_fail (widget != NULL);
   g_return_if_fail (BONOBO_IS_DOCK(widget));
 
-  GNOME_CALL_PARENT (GTK_WIDGET_CLASS, map, (widget));
+  GTK_WIDGET_CLASS(bonobo_dock_parent_class)->map (widget);
 
   dock = BONOBO_DOCK (widget);
 
@@ -518,7 +515,7 @@ bonobo_dock_unmap (GtkWidget *widget)
 
   g_list_foreach (dock->floating_children, unmap_widget_foreach, NULL);
 
-  GNOME_CALL_PARENT (GTK_WIDGET_CLASS, unmap, (widget));
+  GTK_WIDGET_CLASS (bonobo_dock_parent_class)->unmap (widget);
 }
 
 
@@ -660,14 +657,6 @@ bonobo_dock_forall (GtkContainer *container,
     (* callback) (dock->client_area, callback_data);
 }
 
-static void
-bonobo_dock_destroy (GtkObject *object)
-{
-  /* remember, destroy can be run multiple times! */
-  if (GTK_OBJECT_CLASS (parent_class)->destroy)
-    (* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
-}
-
 static void
 bonobo_dock_finalize (GObject *object)
 {
@@ -676,8 +665,8 @@ bonobo_dock_finalize (GObject *object)
   g_free (self->_priv);
   self->_priv = NULL;
 
-  if (G_OBJECT_CLASS (parent_class)->finalize)
-    (* G_OBJECT_CLASS (parent_class)->finalize) (object);
+  G_OBJECT_CLASS (bonobo_dock_parent_class)->finalize (object);
+
 }
 
 
@@ -759,9 +748,9 @@ drag_new (BonoboDock *dock,
       if (where == NULL)
         *area = where = g_list_prepend (*area, new_band);
       else if (where->next == NULL)
-        g_list_append (where, new_band);
+        where = g_list_append (where, new_band);
       else
-        g_list_prepend (where->next, new_band);
+        where = g_list_prepend (where->next, new_band);
 
       new_band_setup (dock, GTK_WIDGET (new_band),
 		      is_vertical ? GTK_ORIENTATION_VERTICAL
@@ -813,7 +802,7 @@ drag_floating (BonoboDock *dock,
   item_widget = GTK_WIDGET (item);
   dock_widget = GTK_WIDGET (dock);
 
-  if (item_widget->parent != dock_widget)
+  if (!item->is_floating && item_widget->parent != dock_widget)
     {
       GtkAllocation *dock_allocation, *client_allocation;
 
@@ -1117,7 +1106,7 @@ get_docked_item_by_name (BonoboDock *dock,
       { NULL, BONOBO_DOCK_BOTTOM },
       { NULL, BONOBO_DOCK_LEFT },
       { NULL, BONOBO_DOCK_RIGHT },
-      { NULL, BONOBO_DOCK_FLOATING },
+      { NULL, BONOBO_DOCK_FLOATING }
     };
     GList *lp;
     guint i;
@@ -1657,10 +1646,10 @@ insert_into_band_list (BonoboDock     *dock,
 }
 
 gint
-bonobo_dock_handle_key_nav (BonoboDock     *dock,
-			    BonoboDockBand *band,
-			    BonoboDockItem *item,
-			    GdkEventKey    *event)
+_bonobo_dock_handle_key_nav (BonoboDock     *dock,
+			     BonoboDockBand *band,
+			     BonoboDockItem *item,
+			     GdkEventKey    *event)
 {
   GList   *entry;
   GList  **band_list;
@@ -1816,7 +1805,7 @@ bonobo_dock_handle_key_nav (BonoboDock     *dock,
   if (bonobo_dock_band_get_num_children (band) == 0)
     gtk_widget_destroy (GTK_WIDGET (band));
 
-  g_object_unref (G_OBJECT (item));
+  g_object_unref (item);
 
   return TRUE;
 }
