@@ -21,21 +21,14 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-macros.h>
 #include <bonobo/bonobo-i18n.h>
 #include <bonobo/bonobo-object.h>
 #include <bonobo/bonobo-selector-widget.h>
 #include <bonobo/bonobo-ui-preferences.h>
 
-#undef GNOME_DISABLE_DEPRECATED /* To get prototype for gnome_i18n_get_language_list() */
-#include <libgnome/gnome-i18n.h>
-
 #include "bonobo-insert-component.xpm"
 
-GNOME_CLASS_BOILERPLATE (BonoboSelectorWidget,
-			 bonobo_selector_widget,
-			 GObject, GTK_TYPE_VBOX);
-
+G_DEFINE_TYPE (BonoboSelectorWidget, bonobo_selector_widget, GTK_TYPE_VBOX)
 
 #define GET_CLASS(o) BONOBO_SELECTOR_WIDGET_CLASS (GTK_OBJECT_GET_CLASS (o))
 
@@ -94,12 +87,14 @@ build_id_query_fragment (const char **required_ids)
 static GSList *
 get_lang_list (void)
 {
-	const GList   *l;
 	static GSList *ret = NULL;
 
 	if (!ret) {
-		for (l = gnome_i18n_get_language_list (NULL); l; l = l->next)
-			ret = g_slist_prepend (ret, l->data);
+		const gchar * const *names;
+		
+		for (names = g_get_language_names (); *names; names++)
+			ret = g_slist_prepend (ret, (gchar *) *names);
+		ret = g_slist_reverse (ret);
 	}
 
 	return ret;
@@ -165,7 +160,7 @@ bonobo_selector_widget_finalize (GObject *object)
 {
 	g_free (BONOBO_SELECTOR_WIDGET (object)->priv);
 
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
+	G_OBJECT_CLASS (bonobo_selector_widget_parent_class)->finalize (object);
 }
 
 static gchar *
@@ -276,7 +271,7 @@ row_activated (GtkTreeView          *tree_view,
 }
 
 static void
-bonobo_selector_widget_instance_init (BonoboSelectorWidget *widget)
+bonobo_selector_widget_init (BonoboSelectorWidget *widget)
 {
 	BonoboSelectorWidget *sel = BONOBO_SELECTOR_WIDGET (widget);
 	GtkWidget *scrolled, *pixmap;
@@ -325,7 +320,7 @@ bonobo_selector_widget_instance_init (BonoboSelectorWidget *widget)
 	frame = gtk_frame_new (_("Description"));
 	gtk_box_pack_start (GTK_BOX (sel), frame, FALSE, TRUE, 0);
 	
-	priv->desc_label = gtk_label_new ("");
+	priv->desc_label = gtk_label_new (NULL);
 	gtk_misc_set_alignment (GTK_MISC (priv->desc_label), 0.0, 0.5);
 	gtk_label_set_line_wrap (GTK_LABEL (priv->desc_label), TRUE);
 	gtk_label_set_justify (GTK_LABEL (priv->desc_label), GTK_JUSTIFY_LEFT);
