@@ -9,17 +9,14 @@
  */
 
 #include <config.h>
-#include <libgnome/gnome-i18n.h>
-#include <libgnome/gnome-macros.h>
+#include <glib/gi18n.h>
 #include <bonobo/bonobo-ui-private.h>
 #include <bonobo/bonobo-ui-toolbar.h>
 #include <bonobo/bonobo-ui-toolbar-item.h>
 #include <bonobo/bonobo-ui-toolbar-popup-item.h>
 
-GNOME_CLASS_BOILERPLATE (BonoboUIToolbar,
-			 bonobo_ui_toolbar,
-			 GObject,
-			 GTK_TYPE_CONTAINER);
+G_DEFINE_TYPE (BonoboUIToolbar, bonobo_ui_toolbar, GTK_TYPE_CONTAINER)
+
 enum {
 	PROP_0,
 	PROP_ORIENTATION,
@@ -144,12 +141,10 @@ item_destroy_cb (GtkObject *object,
 {
 	BonoboUIToolbar *toolbar;
 	BonoboUIToolbarPrivate *priv;
-	GtkWidget *widget;
 
 	toolbar = BONOBO_UI_TOOLBAR (data);
 	priv = toolbar->priv;
 
-	widget = GTK_WIDGET (object);
 	priv->items = g_list_remove (priv->items, object);
 	g_object_unref (object);
 }
@@ -242,7 +237,9 @@ hide_popup_window (BonoboUIToolbar *toolbar)
 
 	priv = toolbar->priv;
 
-	gdk_pointer_ungrab (GDK_CURRENT_TIME);
+	gdk_display_pointer_ungrab
+		(gtk_widget_get_display (priv->popup_window),
+		 GDK_CURRENT_TIME);
 
 	gtk_grab_remove (priv->popup_window);
 	gtk_widget_hide (priv->popup_window);
@@ -285,9 +282,6 @@ static void
 popup_window_map_cb (GtkWidget *widget,
 		     void *data)
 {
-	BonoboUIToolbar *toolbar;
-
-	toolbar = BONOBO_UI_TOOLBAR (data);
 
 	if (gdk_pointer_grab (widget->window, TRUE,
 			      (GDK_BUTTON_PRESS_MASK
@@ -349,11 +343,9 @@ popup_item_toggled_cb (BonoboUIToolbarToggleButtonItem *toggle_button_item,
 		       void *data)
 {
 	BonoboUIToolbar *toolbar;
-	BonoboUIToolbarPrivate *priv;
 	gboolean active;
 
 	toolbar = BONOBO_UI_TOOLBAR (data);
-	priv = toolbar->priv;
 
 	active = bonobo_ui_toolbar_toggle_button_item_get_active (toggle_button_item);
 
@@ -531,6 +523,8 @@ size_allocate_helper (BonoboUIToolbar *toolbar,
 	int extra_space;
 	int num_expandable_items;
 	int popup_item_size;
+	int item_size_left_to_place;
+	int acc_space;
 	gboolean first_expandable;
 	GList *p;
 
@@ -573,6 +567,7 @@ size_allocate_helper (BonoboUIToolbar *toolbar,
 
 	/* first, make a pass through the items to layout the ones that are packed on the right */
 	priv->end_position = allocation->x + available_space;
+	acc_space = 0;
 	for (p = g_list_last (priv->items); p != NULL; p = p->prev) {
 
 		item = BONOBO_UI_TOOLBAR_ITEM (p->data);
@@ -582,14 +577,15 @@ size_allocate_helper (BonoboUIToolbar *toolbar,
 		gtk_widget_get_child_requisition (GTK_WIDGET (item), &child_requisition);
 
 		if (priv->orientation == GTK_ORIENTATION_HORIZONTAL) {
-			available_space -= child_requisition.width;
+			acc_space += child_requisition.width;
+			item_size_left_to_place -= child_requisition.width;
 			priv->end_position -= child_requisition.width;
 			
 			child_allocation.x = priv->end_position;
 			child_allocation.width = child_requisition.width;
 			child_allocation.height = priv->max_height;
 		} else {
-			available_space -= child_requisition.height;
+			acc_space += child_requisition.height;
 			priv->end_position -= child_requisition.height;
 			
 			child_allocation.y = priv->end_position;
@@ -599,6 +595,11 @@ size_allocate_helper (BonoboUIToolbar *toolbar,
 		
 		gtk_widget_size_allocate (GTK_WIDGET (item), &child_allocation);
 	}
+	available_space -= acc_space;
+	if (priv->orientation == GTK_ORIENTATION_HORIZONTAL)
+		item_size_left_to_place = priv->total_width - acc_space;
+	else
+		item_size_left_to_place = priv->total_height - acc_space;
 	
 	/* make a pass through the items to determine how many fit */	
 	space_required = 0;
@@ -608,8 +609,7 @@ size_allocate_helper (BonoboUIToolbar *toolbar,
 	child_allocation.y = allocation->y + border_width;
 
 	for (p = priv->items; p != NULL; p = p->next) {
-		int    item_size;
-		GList *l;
+		int item_size;
 
 		item = BONOBO_UI_TOOLBAR_ITEM (p->data);
 		if (! GTK_WIDGET_VISIBLE (item) || GTK_WIDGET (item)->parent != GTK_WIDGET (toolbar) ||
@@ -623,24 +623,15 @@ size_allocate_helper (BonoboUIToolbar *toolbar,
 		else
 			item_size = child_requisition.height;
 
-		for (l = p->next; l; l = l->next) {
-			GtkWidget *widget = GTK_WIDGET (l->data);
-
-			if (GTK_WIDGET_VISIBLE (widget) &&
-			    widget->parent == GTK_WIDGET (toolbar) &&
-			    ! bonobo_ui_toolbar_item_get_pack_end (BONOBO_UI_TOOLBAR_ITEM (widget)))
-				break;
-		}
-
-		if (!l) {
-			if (space_required + item_size > available_space)
-				break;
-		} else {
-			if (space_required + item_size > available_space - popup_item_size)
-				break;
-		}
-
+/*		g_message ("Item  size %4d, space_required %4d, available %4d left to place %4d",
+			   item_size, space_required, available_space, item_size_left_to_place); */
+		
+		if (item_size_left_to_place > available_space - space_required &&
+		    space_required + item_size > available_space - popup_item_size)
+			break;
+		
 		space_required += item_size;
+		item_size_left_to_place -= item_size;
 
 		if (bonobo_ui_toolbar_item_get_expandable (item))
 			num_expandable_items ++;
@@ -660,8 +651,6 @@ size_allocate_helper (BonoboUIToolbar *toolbar,
 	first_expandable = FALSE;
 
 	for (p = priv->items; p != priv->first_not_fitting_item; p = p->next) {
-		BonoboUIToolbarItem *item;
-		GtkRequisition child_requisition;
 		int expansion_amount;
 
 		item = BONOBO_UI_TOOLBAR_ITEM (p->data);
@@ -737,10 +726,10 @@ impl_dispose (GObject *object)
 	priv->popup_window = NULL;
 
 	if (priv->tooltips)
-		gtk_object_sink (GTK_OBJECT (priv->tooltips));
+		g_object_ref_sink (GTK_OBJECT (priv->tooltips));
 	priv->tooltips = NULL;
 
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (object));
+	G_OBJECT_CLASS (bonobo_ui_toolbar_parent_class)->dispose (object);
 }
 
 static void
@@ -751,7 +740,7 @@ impl_finalize (GObject *object)
 	g_list_free (toolbar->priv->items);
 	g_free (toolbar->priv);
 
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
+	G_OBJECT_CLASS (bonobo_ui_toolbar_parent_class)->finalize (object);
 }
 
 /* GtkWidget methods.  */
@@ -804,10 +793,8 @@ impl_size_allocate (GtkWidget *widget,
 		    GtkAllocation *allocation)
 {
 	BonoboUIToolbar *toolbar;
-	BonoboUIToolbarPrivate *priv;
 
 	toolbar = BONOBO_UI_TOOLBAR (widget);
-	priv = toolbar->priv;
 
 	size_allocate_helper (toolbar, allocation);
 }
@@ -870,6 +857,7 @@ impl_expose_event (GtkWidget *widget,
 {
 	BonoboUIToolbar *toolbar;
 	BonoboUIToolbarPrivate *priv;
+	GtkShadowType shadow_type;
 	GList *p;
 
 	if (! GTK_WIDGET_DRAWABLE (widget))
@@ -878,6 +866,18 @@ impl_expose_event (GtkWidget *widget,
 	toolbar = BONOBO_UI_TOOLBAR (widget);
 	priv = toolbar->priv;
 
+	gtk_widget_style_get (widget, "shadow_type", &shadow_type, NULL);
+
+	gtk_paint_box (widget->style,
+		       widget->window,
+		       GTK_WIDGET_STATE (widget),
+		       shadow_type,
+		       &event->area, widget, "toolbar",
+		       widget->allocation.x,
+		       widget->allocation.y,
+		       widget->allocation.width,
+		       widget->allocation.height);
+
 	for (p = priv->items; p != NULL; p = p->next) {
 		GtkWidget *item_widget;
 
@@ -1089,7 +1089,6 @@ bonobo_ui_toolbar_class_init (BonoboUIToolbarClass *toolbar_class)
 	widget_class->map           = impl_map;
 	widget_class->unmap         = impl_unmap;
 	widget_class->expose_event  = impl_expose_event;
-	widget_class->focus         = bonobo_widget_clobber_focus;
 
 	container_class = GTK_CONTAINER_CLASS (toolbar_class);
 	container_class->remove = impl_remove;
@@ -1155,10 +1154,19 @@ bonobo_ui_toolbar_class_init (BonoboUIToolbarClass *toolbar_class)
 				NULL, NULL,
 				g_cclosure_marshal_VOID__VOID,
 				G_TYPE_NONE, 0);
+
+	gtk_widget_class_install_style_property (
+	        widget_class,
+		g_param_spec_enum ("shadow_type",
+				   _("Shadow type"),
+				   _("Style of bevel around the toolbar"),
+				   GTK_TYPE_SHADOW_TYPE,
+				   GTK_SHADOW_OUT,
+				   G_PARAM_READABLE));
 }
 
 static void
-bonobo_ui_toolbar_instance_init (BonoboUIToolbar *toolbar)
+bonobo_ui_toolbar_init (BonoboUIToolbar *toolbar)
 {
 	AtkObject *ao;
 	BonoboUIToolbarStyle style;
@@ -1312,8 +1320,7 @@ bonobo_ui_toolbar_insert (BonoboUIToolbar *toolbar,
 	 * child of either this widget, or the popup window.
 	 */
 	if (!g_list_find (priv->items, item)) {
-		g_object_ref (item);
-		gtk_object_sink (GTK_OBJECT (item));
+		g_object_ref_sink (item);
 		priv->items = g_list_insert (priv->items, item, position);
 	}
 
