@@ -187,12 +187,14 @@ int
 main (int argc, char **argv)
 {
 	CORBA_Environment ev;
+	GnomeProgram *program;
+
 	CORBA_exception_init (&ev);
 
 	/* Encorage -lefence to play ball */
 	{ char *tmp = malloc (4); if (tmp) free (tmp); }
 
-	gnome_program_init ("test-sensitivity", VERSION,
+	program = gnome_program_init ("test-sensitivity", VERSION,
 			    LIBBONOBOUI_MODULE,
 			    argc, argv, NULL);
 
@@ -204,5 +206,7 @@ main (int argc, char **argv)
 
 	bonobo_main ();
 
+	g_object_unref (program);
+
 	return bonobo_ui_debug_shutdown ();
 }
